
#ifndef DCM_API_H
#define DCM_API_H

typedef unsigned char CanIf_HwHandleType;
typedef unsigned char CanIf_CanDlcType;
typedef unsigned char CanIf_CanDataType;
typedef unsigned int  CanIf_CanIdType;


/* 此函数在收到CAN数据后面调用 */
extern void RxIndicationCanIf_Messages(
		CanIf_HwHandleType Hrh, 					/* 此参数暂时不明，先置0 */
		CanIf_CanIdType LeCanIf_e_CanId, 			/* CAN ID */
		CanIf_CanDlcType LeCanIf_e_CanDlc, 			/* CAN数据长度 */
		CanIf_CanDataType* LeCanIf_e_CanSduPtr);	/* 指向CAN接收数据缓存 */
/* 初始化 上电调用 */
extern void InitCanTp_Parameter(void);
extern void InitDcm_Parameter (void);

/**下面函数在主程序调用，能否在中断里调用要具体处理时间，**/
extern void MngDcm_1ms_Sever(void);
void BootProgramSessionDeal(void);
#endif

